@@ -21,7 +21,6 @@
 #include "src/priv.h"
 #include "classes/http.h"
 
-
 zend_class_entry *php_event_ce;
 zend_class_entry *php_event_base_ce;
 zend_class_entry *php_event_config_ce;
@@ -975,8 +974,8 @@ static zend_always_inline void register_classes()/*{{{*/
 	ce->ce_flags |= ZEND_ACC_FINAL;
 	zend_hash_init(&event_properties, 2, NULL, free_prop_handler, 1);
 	PHP_EVENT_ADD_CLASS_PROPERTIES(&event_properties, event_property_entries);
-	PHP_EVENT_DECL_PROP_NULL(ce, "pending", ZEND_ACC_PUBLIC);
-	PHP_EVENT_DECL_PROP_NULL(ce, "data",    ZEND_ACC_PUBLIC);
+	PHP_EVENT_DECL_PROP_NULL(ce, pending, ZEND_ACC_PUBLIC);
+	PHP_EVENT_DECL_PROP_NULL(ce, data,    ZEND_ACC_PUBLIC);
 	zend_hash_add_ptr(&classes, ce->name, &event_properties);
 
 	PHP_EVENT_REGISTER_CLASS("EventBase", event_base_object_create, php_event_base_ce,
@@ -995,12 +994,12 @@ static zend_always_inline void register_classes()/*{{{*/
 	ce->ce_flags |= ZEND_ACC_FINAL;
 	zend_hash_init(&event_bevent_properties, 4, NULL, free_prop_handler, 1);
 	PHP_EVENT_ADD_CLASS_PROPERTIES(&event_bevent_properties, event_bevent_property_entries);
-	PHP_EVENT_DECL_PROP_NULL(ce, "priority", ZEND_ACC_PUBLIC);
-	PHP_EVENT_DECL_PROP_NULL(ce, "fd",       ZEND_ACC_PUBLIC);
-	PHP_EVENT_DECL_PROP_NULL(ce, "input",    ZEND_ACC_PUBLIC);
-	PHP_EVENT_DECL_PROP_NULL(ce, "output",   ZEND_ACC_PUBLIC);
+	PHP_EVENT_DECL_PROP_NULL(ce, priority, ZEND_ACC_PUBLIC);
+	PHP_EVENT_DECL_PROP_NULL(ce, fd,       ZEND_ACC_PUBLIC);
+	PHP_EVENT_DECL_PROP_NULL(ce, input,    ZEND_ACC_PUBLIC);
+	PHP_EVENT_DECL_PROP_NULL(ce, output,   ZEND_ACC_PUBLIC);
 #if LIBEVENT_VERSION_NUMBER >= 0x02010100
-	PHP_EVENT_DECL_PROP_NULL(ce, "allow_ssl_dirty_shutdown", ZEND_ACC_PUBLIC);
+	PHP_EVENT_DECL_PROP_NULL(ce, allow_ssl_dirty_shutdown, ZEND_ACC_PUBLIC);
 #endif
 	zend_hash_add_ptr(&classes, ce->name, &event_bevent_properties);
 
@@ -1009,8 +1008,8 @@ static zend_always_inline void register_classes()/*{{{*/
 	ce = php_event_buffer_ce;
 	zend_hash_init(&event_buffer_properties, 2, NULL, free_prop_handler, 1);
 	PHP_EVENT_ADD_CLASS_PROPERTIES(&event_buffer_properties, event_buffer_property_entries);
-	PHP_EVENT_DECL_PROP_NULL(ce, "length",           ZEND_ACC_PUBLIC);
-	PHP_EVENT_DECL_PROP_NULL(ce, "contiguous_space", ZEND_ACC_PUBLIC);
+	PHP_EVENT_DECL_PROP_NULL(ce, length,           ZEND_ACC_PUBLIC);
+	PHP_EVENT_DECL_PROP_NULL(ce, contiguous_space, ZEND_ACC_PUBLIC);
 	zend_hash_add_ptr(&classes, ce->name, &event_buffer_properties);
 
 #if HAVE_EVENT_EXTRA_LIB
@@ -1025,7 +1024,7 @@ static zend_always_inline void register_classes()/*{{{*/
 	ce->ce_flags |= ZEND_ACC_FINAL;
 	zend_hash_init(&event_listener_properties, 1, NULL, free_prop_handler, 1);
 	PHP_EVENT_ADD_CLASS_PROPERTIES(&event_listener_properties, event_listener_property_entries);
-	PHP_EVENT_DECL_PROP_NULL(ce, "fd", ZEND_ACC_PUBLIC);
+	PHP_EVENT_DECL_PROP_NULL(ce, fd, ZEND_ACC_PUBLIC);
 	zend_hash_add_ptr(&classes, ce->name, &event_listener_properties);
 
 	PHP_EVENT_REGISTER_CLASS("EventHttpConnection", event_http_conn_object_create,
@@ -1058,8 +1057,8 @@ static zend_always_inline void register_classes()/*{{{*/
 	ce->ce_flags |= ZEND_ACC_FINAL;
 	zend_hash_init(&event_ssl_context_properties, 2, NULL, free_prop_handler, 1);
 	PHP_EVENT_ADD_CLASS_PROPERTIES(&event_ssl_context_properties, event_ssl_context_property_entries);
-	PHP_EVENT_DECL_PROP_NULL(ce, "local_cert", ZEND_ACC_PUBLIC);
-	PHP_EVENT_DECL_PROP_NULL(ce, "local_pk",   ZEND_ACC_PUBLIC);
+	PHP_EVENT_DECL_PROP_NULL(ce, local_cert, ZEND_ACC_PUBLIC);
+	PHP_EVENT_DECL_PROP_NULL(ce, local_pk,   ZEND_ACC_PUBLIC);
 	zend_hash_add_ptr(&classes, ce->name, &event_ssl_context_properties);
 #endif /* HAVE_EVENT_OPENSSL_LIB */
 }/*}}}*/
@@ -1247,13 +1246,17 @@ PHP_MINIT_FUNCTION(event)
 	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_buffer_ce, PTR_ADD,         EVBUFFER_PTR_ADD);
 
 #ifdef HAVE_EVENT_OPENSSL_LIB
+# ifdef HAVE_SSL2
 	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, SSLv2_CLIENT_METHOD,  PHP_EVENT_SSLv2_CLIENT_METHOD);
-	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, SSLv3_CLIENT_METHOD,  PHP_EVENT_SSLv3_CLIENT_METHOD);
-	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, SSLv23_CLIENT_METHOD, PHP_EVENT_SSLv23_CLIENT_METHOD);
-	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, TLS_CLIENT_METHOD,    PHP_EVENT_TLS_CLIENT_METHOD);
 	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, SSLv2_SERVER_METHOD,  PHP_EVENT_SSLv2_SERVER_METHOD);
-	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, SSLv3_SERVER_METHOD,  PHP_EVENT_SSLv3_SERVER_METHOD);
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, SSLv23_CLIENT_METHOD, PHP_EVENT_SSLv23_CLIENT_METHOD);
 	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, SSLv23_SERVER_METHOD, PHP_EVENT_SSLv23_SERVER_METHOD);
+# endif
+# ifdef HAVE_SSL3
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, SSLv3_CLIENT_METHOD,  PHP_EVENT_SSLv3_CLIENT_METHOD);
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, SSLv3_SERVER_METHOD,  PHP_EVENT_SSLv3_SERVER_METHOD);
+# endif
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, TLS_CLIENT_METHOD,    PHP_EVENT_TLS_CLIENT_METHOD);
 	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, TLS_SERVER_METHOD,    PHP_EVENT_TLS_SERVER_METHOD);
 	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, TLSv11_CLIENT_METHOD, PHP_EVENT_TLSv11_CLIENT_METHOD);
 	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, TLSv11_SERVER_METHOD, PHP_EVENT_TLSv11_SERVER_METHOD);
@@ -1278,6 +1281,28 @@ PHP_MINIT_FUNCTION(event)
 	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, OPT_REQUIRE_CLIENT_CERT,      PHP_EVENT_OPT_REQUIRE_CLIENT_CERT);
 	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, OPT_VERIFY_CLIENT_ONCE,       PHP_EVENT_OPT_VERIFY_CLIENT_ONCE);
 
+	PHP_EVENT_REG_CLASS_CONST_STRING(php_event_ssl_context_ce, OPENSSL_VERSION_TEXT,       OPENSSL_VERSION_TEXT);
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce,   OPENSSL_VERSION_NUMBER,     OPENSSL_VERSION_NUMBER);
+#ifdef LIBRESSL_VERSION_NUMBER
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce,   LIBRESSL_VERSION_NUMBER,     LIBRESSL_VERSION_NUMBER);
+#endif
+#ifdef LIBRESSL_VERSION_TEXT
+	PHP_EVENT_REG_CLASS_CONST_STRING(php_event_ssl_context_ce, LIBRESSL_VERSION_TEXT,       LIBRESSL_VERSION_TEXT);
+#endif
+
+
+	/* Constants for EventSslContext::setMinProtoVersion */
+#if OPENSSL_VERSION_NUMBER >= 0x10100000L
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, SSL3_VERSION,    SSL3_VERSION);
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, TLS1_VERSION,    TLS1_VERSION);
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, TLS1_1_VERSION,  TLS1_1_VERSION);
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, TLS1_2_VERSION,  TLS1_2_VERSION);
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, DTLS1_VERSION,   DTLS1_VERSION);
+# ifdef DTLS1_2_VERSION /* May be missing in libressl*/
+	PHP_EVENT_REG_CLASS_CONST_LONG(php_event_ssl_context_ce, DTLS1_2_VERSION, DTLS1_2_VERSION);
+# endif
+#endif
+
 	/* Initialize openssl library */
 	SSL_load_error_strings();
 	SSL_library_init();
@@ -1317,15 +1342,24 @@ PHP_MINIT_FUNCTION(event)
 PHP_MSHUTDOWN_FUNCTION(event)
 {
 #ifdef HAVE_EVENT_OPENSSL_LIB
+# ifndef LIBRESSL_VERSION_NUMBER
 	FIPS_mode_set(0);
+# endif
 	CONF_modules_unload(1);
 	/* Removes memory allocated when loading digest and cipher names
 	 * in the OpenSSL_add_all_ family of functions */
 	EVP_cleanup();
 	CRYPTO_cleanup_all_ex_data();
+# if OPENSSL_VERSION_NUMBER >= 0x10100000L
+	/* No need in ERR_remove_thread_state, or ERR_remove_state, since OpenSSL
+	 * do all thread initialisation/deinitialisation automatically */
+# elif OPENSSL_VERSION_NUMBER >= 0x10000000L
+	ERR_remove_thread_state(NULL);
+# else
 	ERR_remove_state(0);
+# endif
 	ERR_free_strings();
-#endif
+#endif /* HAVE_EVENT_OPENSSL_LIB */
 
 #if LIBEVENT_VERSION_NUMBER >= 0x02010000
 	/* libevent_global_shutdown is available since libevent 2.1.0-alpha.
@@ -1397,6 +1431,7 @@ PHP_MINFO_FUNCTION(event)
 	php_info_print_table_row(2, "Thread safety support", "disabled");
 #endif
 
+
 	php_info_print_table_row(2, "Extension version", PHP_EVENT_VERSION);
 	php_info_print_table_row(2, "libevent2 headers version", LIBEVENT_VERSION);
 	php_info_print_table_end();
