@@ -23,10 +23,6 @@
 ZEND_BEGIN_ARG_INFO(arginfo_event__void, 0)
 ZEND_END_ARG_INFO();
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_event_base_config_1, 0, 0, 1)
-	ZEND_ARG_INFO(0, config)
-ZEND_END_ARG_INFO();
-
 ZEND_BEGIN_ARG_INFO_EX(arginfo_event_base__construct, 0, 0, 0)
 	ZEND_ARG_INFO(0, cfg)
 ZEND_END_ARG_INFO();
@@ -130,10 +126,6 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_bufferevent_connect, 0, 0, 1)
 	ZEND_ARG_INFO(0, addr)
 ZEND_END_ARG_INFO();
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_bufferevent_connect_unix, 0, 0, 1)
-	ZEND_ARG_INFO(0, addr)
-ZEND_END_ARG_INFO();
-
 ZEND_BEGIN_ARG_INFO_EX(arginfo_bufferevent_connecthost, 0, 0, 3)
 	ZEND_ARG_INFO(0, dns_base)
 	ZEND_ARG_INFO(0, hostname)
@@ -251,12 +243,6 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_evbuffer_search_eol, 0, 0, 0)
 	ZEND_ARG_INFO(0, eol_style)
 ZEND_END_ARG_INFO();
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_evbuffer_set_position, 0, 0, 3)
-	ZEND_ARG_INFO(1, pos)
-	ZEND_ARG_INFO(0, value)
-	ZEND_ARG_INFO(0, how)
-ZEND_END_ARG_INFO();
-
 ZEND_BEGIN_ARG_INFO_EX(arginfo_evbuffer_pullup, 0, 0, 1)
 	ZEND_ARG_INFO(0, size)
 ZEND_END_ARG_INFO();
@@ -401,6 +387,12 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_event_ssl_context__construct, 0, 0, 2)
 	ZEND_ARG_INFO(0, options)
 ZEND_END_ARG_INFO();
 
+#if OPENSSL_VERSION_NUMBER >= 0x10100000L
+ZEND_BEGIN_ARG_INFO_EX(arginfo_event_ssl_context_set_min_proto_version, 0, 0, 1)
+	ZEND_ARG_INFO(0, proto)
+ZEND_END_ARG_INFO();
+#endif
+
 ZEND_BEGIN_ARG_INFO_EX(arginfo_event_util_get_socket_name, 0, 0, 2)
 	ZEND_ARG_INFO(0, socket)
 	ZEND_ARG_INFO(1, address)
@@ -470,16 +462,6 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_evconnlistener__construct, 0, 0, 6)
 	ZEND_ARG_INFO(0, target)
 ZEND_END_ARG_INFO();
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_evconnlistener_new_bind, 0, 0, 5)
-	ZEND_ARG_OBJ_INFO(0, base, EventBase, 0)
-	ZEND_ARG_INFO(0, cb)
-	ZEND_ARG_INFO(0, data)
-	ZEND_ARG_INFO(0, flags)
-	ZEND_ARG_INFO(0, backlog)
-	ZEND_ARG_INFO(0, addr)
-	ZEND_ARG_INFO(0, port)
-ZEND_END_ARG_INFO();
-
 ZEND_BEGIN_ARG_INFO_EX(arginfo_evconnlistener_set_cb, 0, 0, 1)
 	ZEND_ARG_INFO(0, cb)
 	ZEND_ARG_INFO(0, arg)
@@ -729,6 +711,7 @@ const zend_function_entry php_event_http_req_ce_functions[] = {
 
 const zend_function_entry php_event_listener_ce_functions[] = {
 	PHP_ME(EventListener, __construct,      arginfo_evconnlistener__construct,   ZEND_ACC_PUBLIC  | ZEND_ACC_CTOR)
+	PHP_ME(EventListener, free,             arginfo_event__void,                 ZEND_ACC_PUBLIC)
 	PHP_ME(EventListener, enable,           arginfo_event__void,                 ZEND_ACC_PUBLIC)
 	PHP_ME(EventListener, disable,          arginfo_event__void,                 ZEND_ACC_PUBLIC)
 	PHP_ME(EventListener, setCallback,      arginfo_evconnlistener_set_cb,       ZEND_ACC_PUBLIC)
@@ -747,6 +730,10 @@ const zend_function_entry php_event_listener_ce_functions[] = {
 #ifdef HAVE_EVENT_OPENSSL_LIB
 const zend_function_entry php_event_ssl_context_ce_functions[] = {/* {{{ */
 	PHP_ME(EventSslContext, __construct, arginfo_event_ssl_context__construct, ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
+#if OPENSSL_VERSION_NUMBER >= 0x10100000L && !defined(LIBRESSL_VERSION_NUMBER)
+	PHP_ME(EventSslContext, setMinProtoVersion, arginfo_event_ssl_context_set_min_proto_version, ZEND_ACC_PUBLIC)
+	PHP_ME(EventSslContext, setMaxProtoVersion, arginfo_event_ssl_context_set_min_proto_version, ZEND_ACC_PUBLIC)
+#endif
 
 	PHP_FE_END
 };
